'''OpenGL extension NV.fence

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_fence'
_DEPRECATED = False
GL_ALL_COMPLETED_NV = constant.Constant( 'GL_ALL_COMPLETED_NV', 0x84F2 )
GL_FENCE_STATUS_NV = constant.Constant( 'GL_FENCE_STATUS_NV', 0x84F3 )
GL_FENCE_CONDITION_NV = constant.Constant( 'GL_FENCE_CONDITION_NV', 0x84F4 )
glDeleteFencesNV = platform.createExtensionFunction( 
'glDeleteFencesNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteFencesNV(GLsizei(n), GLuintArray(fences)) -> None',
argNames=('n','fences',),
deprecated=_DEPRECATED,
)

glGenFencesNV = platform.createExtensionFunction( 
'glGenFencesNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenFencesNV(GLsizei(n), GLuintArray(fences)) -> None',
argNames=('n','fences',),
deprecated=_DEPRECATED,
)

glIsFenceNV = platform.createExtensionFunction( 
'glIsFenceNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsFenceNV(GLuint(fence)) -> constants.GLboolean',
argNames=('fence',),
deprecated=_DEPRECATED,
)

glTestFenceNV = platform.createExtensionFunction( 
'glTestFenceNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glTestFenceNV(GLuint(fence)) -> constants.GLboolean',
argNames=('fence',),
deprecated=_DEPRECATED,
)

glGetFenceivNV = platform.createExtensionFunction( 
'glGetFenceivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetFenceivNV(GLuint(fence), GLenum(pname), GLintArray(params)) -> None',
argNames=('fence','pname','params',),
deprecated=_DEPRECATED,
)

glFinishFenceNV = platform.createExtensionFunction( 
'glFinishFenceNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glFinishFenceNV(GLuint(fence)) -> None',
argNames=('fence',),
deprecated=_DEPRECATED,
)

glSetFenceNV = platform.createExtensionFunction( 
'glSetFenceNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glSetFenceNV(GLuint(fence), GLenum(condition)) -> None',
argNames=('fence','condition',),
deprecated=_DEPRECATED,
)


def glInitFenceNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension INGR.blend_func_separate

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_INGR_blend_func_separate'
_DEPRECATED = False

glBlendFuncSeparateINGR = platform.createExtensionFunction( 
'glBlendFuncSeparateINGR',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,),
doc='glBlendFuncSeparateINGR(GLenum(sfactorRGB), GLenum(dfactorRGB), GLenum(sfactorAlpha), GLenum(dfactorAlpha)) -> None',
argNames=('sfactorRGB','dfactorRGB','sfactorAlpha','dfactorAlpha',),
deprecated=_DEPRECATED,
)


def glInitBlendFuncSeparateINGR():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SUN.triangle_list

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SUN_triangle_list'
_DEPRECATED = False
GL_RESTART_SUN = constant.Constant( 'GL_RESTART_SUN', 0x1 )
GL_REPLACE_MIDDLE_SUN = constant.Constant( 'GL_REPLACE_MIDDLE_SUN', 0x2 )
GL_REPLACE_OLDEST_SUN = constant.Constant( 'GL_REPLACE_OLDEST_SUN', 0x3 )
GL_TRIANGLE_LIST_SUN = constant.Constant( 'GL_TRIANGLE_LIST_SUN', 0x81D7 )
GL_REPLACEMENT_CODE_SUN = constant.Constant( 'GL_REPLACEMENT_CODE_SUN', 0x81D8 )
glget.addGLGetConstant( GL_REPLACEMENT_CODE_SUN, (1,) )
GL_REPLACEMENT_CODE_ARRAY_SUN = constant.Constant( 'GL_REPLACEMENT_CODE_ARRAY_SUN', 0x85C0 )
GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN = constant.Constant( 'GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN', 0x85C1 )
glget.addGLGetConstant( GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN, (1,) )
GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN = constant.Constant( 'GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN', 0x85C2 )
glget.addGLGetConstant( GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN, (1,) )
GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN = constant.Constant( 'GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN', 0x85C3 )
GL_R1UI_V3F_SUN = constant.Constant( 'GL_R1UI_V3F_SUN', 0x85C4 )
GL_R1UI_C4UB_V3F_SUN = constant.Constant( 'GL_R1UI_C4UB_V3F_SUN', 0x85C5 )
GL_R1UI_C3F_V3F_SUN = constant.Constant( 'GL_R1UI_C3F_V3F_SUN', 0x85C6 )
GL_R1UI_N3F_V3F_SUN = constant.Constant( 'GL_R1UI_N3F_V3F_SUN', 0x85C7 )
GL_R1UI_C4F_N3F_V3F_SUN = constant.Constant( 'GL_R1UI_C4F_N3F_V3F_SUN', 0x85C8 )
GL_R1UI_T2F_V3F_SUN = constant.Constant( 'GL_R1UI_T2F_V3F_SUN', 0x85C9 )
GL_R1UI_T2F_N3F_V3F_SUN = constant.Constant( 'GL_R1UI_T2F_N3F_V3F_SUN', 0x85CA )
GL_R1UI_T2F_C4F_N3F_V3F_SUN = constant.Constant( 'GL_R1UI_T2F_C4F_N3F_V3F_SUN', 0x85CB )
glReplacementCodeuiSUN = platform.createExtensionFunction( 
'glReplacementCodeuiSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glReplacementCodeuiSUN(GLuint(code)) -> None',
argNames=('code',),
deprecated=_DEPRECATED,
)

glReplacementCodeusSUN = platform.createExtensionFunction( 
'glReplacementCodeusSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLushort,),
doc='glReplacementCodeusSUN(GLushort(code)) -> None',
argNames=('code',),
deprecated=_DEPRECATED,
)

glReplacementCodeubSUN = platform.createExtensionFunction( 
'glReplacementCodeubSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLubyte,),
doc='glReplacementCodeubSUN(GLubyte(code)) -> None',
argNames=('code',),
deprecated=_DEPRECATED,
)

glReplacementCodeuivSUN = platform.createExtensionFunction( 
'glReplacementCodeuivSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,),
doc='glReplacementCodeuivSUN(GLuintArray(code)) -> None',
argNames=('code',),
deprecated=_DEPRECATED,
)

glReplacementCodeusvSUN = platform.createExtensionFunction( 
'glReplacementCodeusvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glReplacementCodeusvSUN(GLushortArray(code)) -> None',
argNames=('code',),
deprecated=_DEPRECATED,
)

glReplacementCodeubvSUN = platform.createExtensionFunction( 
'glReplacementCodeubvSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLubyteArray,),
doc='glReplacementCodeubvSUN(GLubyteArray(code)) -> None',
argNames=('code',),
deprecated=_DEPRECATED,
)

glReplacementCodePointerSUN = platform.createExtensionFunction( 
'glReplacementCodePointerSUN',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,ctypes.POINTER(ctypes.c_void_p),),
doc='glReplacementCodePointerSUN(GLenum(type), GLsizei(stride), POINTER(ctypes.c_void_p)(pointer)) -> None',
argNames=('type','stride','pointer',),
deprecated=_DEPRECATED,
)


def glInitTriangleListSUN():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.subtexture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_subtexture'
_DEPRECATED = False

glTexSubImage1DEXT = platform.createExtensionFunction( 
'glTexSubImage1DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTexSubImage1DEXT(GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('target','level','xoffset','width','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTexSubImage2DEXT = platform.createExtensionFunction( 
'glTexSubImage2DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTexSubImage2DEXT(GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('target','level','xoffset','yoffset','width','height','format','type','pixels',),
deprecated=_DEPRECATED,
)


def glInitSubtextureEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.timer_query

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_timer_query'
_DEPRECATED = False
GL_TIME_ELAPSED_EXT = constant.Constant( 'GL_TIME_ELAPSED_EXT', 0x88BF )
glGetQueryObjecti64vEXT = platform.createExtensionFunction( 
'glGetQueryObjecti64vEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLint64Array,),
doc='glGetQueryObjecti64vEXT(GLuint(id), GLenum(pname), GLint64Array(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)

glGetQueryObjectui64vEXT = platform.createExtensionFunction( 
'glGetQueryObjectui64vEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLuint64Array,),
doc='glGetQueryObjectui64vEXT(GLuint(id), GLenum(pname), GLuint64Array(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)


def glInitTimerQueryEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



#! /usr/bin/env python
"""Script to generate the raw sub-package APIs

Basically just drives OpenGLGenerator with options to produce
the various modules we want...
"""
import os, sys, logging, re, compileall
import openglgenerator
from OpenGL import platform
try:
    from OpenGL import GL
except (ImportError, AttributeError), err:
    pass

# put our OpenGL directory on the search path, just in case...
sys.path.insert( 0, os.path.abspath( '..' ) )

log = logging.getLogger( 'generateraw' )

MODULE_DEFINITIONS = [
    ('GL', ('gl[A-Z0-9].*','GL_.*')),
    ('GLU',('glu[A-Z0-9].*','GLU[_a-z0-9].*')),
    ('GLUT', ('glut[A-Z0-9].*','GLUT[_a-z0-9].*')),
    ('GLE', None),
    ('GLX', None),
    ('WGL', ('wgl.*','WGL.*',),
    ('AGL', None),
]
def filterModules( arguments ):
    """Filter the set of modules according to command-line options

    Basically no args == do everything, otherwise only process modules
    declared here...
    """
    if arguments:
        definitions = [
            x for x in MODULE_DEFINITIONS
            if x[0] in arguments
        ]
    else:
        definitions = MODULE_DEFINITIONS
    return definitions

def main():
    baseModules = [
        'OpenGL.constants',
    ]
    known_symbols = openglgenerator.OpenGLGenerator.loadKnownSymbols( 
        baseModules 
    )
    definedSymbols = known_symbols.copy()
    for (module,expressions) in filterModules( sys.argv[1:] ):
        log.info( "Processing module: %s", module )
        if expressions:
            expressions = [re.compile(e) for e in expressions]
        xmlFile = '%s.xml'%( module.lower(), )
        directory = '../OpenGL/raw/%(module)s'%locals()
        try:
            os.makedirs( directory )
        except OSError, err:
            pass
        constantsFile = os.path.join( directory, 'constants.py' )
        rawFile = os.path.join( directory, '__init__.py' )
        open( rawFile, 'w' ).close()
        annotationsFile = os.path.join( directory, 'annotations.py' )
        dll = getattr( platform, module, None )
        if dll and os.path.isfile( xmlFile ):
            log.info( "Found DLL: %s and have XML source file: %s", dll, xmlFile )
            # first the constants file...
            log.info( "Generating constants %s", constantsFile )
            gen = openglgenerator.OpenGLGenerator(
                open(constantsFile,'w'),
                generate_comments = False,
                searched_dlls = [ dll ],
                known_symbols = definedSymbols,
                module_header = '''"""Constants for OpenGL.%(module)s

Automatically generated by the generateraw script, do not edit!
"""
'''%locals(),
            )
            items = gen.load_typedefs( xmlFile , types = [
                openglgenerator.codegenerator.typedesc.Variable, # ick!
            ], expressions = expressions)
            gen.produce( items )
            gen.output.close()
            
            log.info( "Generating raw API %s", rawFile )
            constantSymbols = gen.loadKnownSymbols( 
                ['OpenGL.raw.%(module)s.constants'%locals()], 
                flags = gen.EXPORT_SYMBOL, # don't import, do export
                doReload = True,
            )
            constantSymbols.update( definedSymbols )
            constantSymbols.update( known_symbols )
            gen = openglgenerator.OpenGLGenerator(
                open(rawFile,'w'),
                generate_comments = True,
                searched_dlls = [ dll ],
                known_symbols = constantSymbols,
                module_header = '''# -*- coding: iso-8859-1 -*-
"""Raw (C-style) API for OpenGL.%(module)s

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw.%(module)s.constants import *
'''%locals(),
            )
            items = gen.load_typedefs( xmlFile, expressions = expressions )
            gen.produce( items )
            gen.output.close()

            log.info( "Generating annotations %s", annotationsFile )
            gen = openglgenerator.OpenGLGenerator(
                open(annotationsFile,'w'),
                generate_comments = True,
                searched_dlls = [ dll ],
                emitters = [ openglgenerator.OpenGLDecorator() ],
                known_symbols = definedSymbols,
                module_header = '''"""Array-size annotations for OpenGL.raw.%(module)s

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw import %(module)s as raw
'''%locals(),
            )
            items = gen.load_typedefs( xmlFile, types = [
                openglgenerator.codegenerator.typedesc.Function, # ick!
            ], expressions = expressions)
            gen.produce( items )
            gen.output.close()

            log.info( """Suppressing future output of already-defined functions/structures: %s""", module )
            definedSymbols.update( 
                gen.loadKnownSymbols( 
                    ['OpenGL.raw.%(module)s'%locals()], 
                    flags = 0, # neither import nor export from future operations...
                    doReload = True,
                )
            )
            definedSymbols.update( 
                gen.loadKnownSymbols( 
                    ['OpenGL.raw.%(module)s.constants'%locals()], 
                    flags = 0, # suppress future export of the constants
                    doReload = True,
                ) 
            )
            definedSymbols.update( known_symbols )
            if module == 'GL':
                # filter out the higher GL version stuff as well...
                # obviously you need to have the version stuff generated already 
                # to make this work!
                for version in ('1_2','1_3','1_4','1_5','2_0'):
                    log.info( 'Suppressing exports from Core GL Version %s', version )
                    definedSymbols.update( 
                        gen.loadKnownSymbols( 
                            ['OpenGL.raw.GL.VERSION.GL_%(version)s'%locals()], 
                            flags = 0, # suppress future export of the constants
                            doReload = True,
                        ) 
                    )
            path = '../OpenGL/raw/%(module)s'%locals()
            log.info( 'Forcing recompilation of %s', path )
            compileall.compile_dir(path, maxlevels=2, force=True, quiet=True)
    

if __name__ == "__main__":
    logging.basicConfig()
    #logging.getLogger( 'codegenerator' ).setLevel( logging.DEBUG )
    log.setLevel( logging.INFO )
    main()



'''OpenGL extension VERSION.GL_2_0

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_2_0'
_DEPRECATED = False
GL_BLEND_EQUATION_RGB = constant.Constant( 'GL_BLEND_EQUATION_RGB', 0x8009 )
GL_VERTEX_ATTRIB_ARRAY_ENABLED = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_ENABLED', 0x8622 )
GL_VERTEX_ATTRIB_ARRAY_SIZE = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_SIZE', 0x8623 )
GL_VERTEX_ATTRIB_ARRAY_STRIDE = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_STRIDE', 0x8624 )
GL_VERTEX_ATTRIB_ARRAY_TYPE = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_TYPE', 0x8625 )
GL_CURRENT_VERTEX_ATTRIB = constant.Constant( 'GL_CURRENT_VERTEX_ATTRIB', 0x8626 )
GL_VERTEX_PROGRAM_POINT_SIZE = constant.Constant( 'GL_VERTEX_PROGRAM_POINT_SIZE', 0x8642 )
GL_VERTEX_ATTRIB_ARRAY_POINTER = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_POINTER', 0x8645 )
GL_STENCIL_BACK_FUNC = constant.Constant( 'GL_STENCIL_BACK_FUNC', 0x8800 )
GL_STENCIL_BACK_FAIL = constant.Constant( 'GL_STENCIL_BACK_FAIL', 0x8801 )
GL_STENCIL_BACK_PASS_DEPTH_FAIL = constant.Constant( 'GL_STENCIL_BACK_PASS_DEPTH_FAIL', 0x8802 )
GL_STENCIL_BACK_PASS_DEPTH_PASS = constant.Constant( 'GL_STENCIL_BACK_PASS_DEPTH_PASS', 0x8803 )
GL_MAX_DRAW_BUFFERS = constant.Constant( 'GL_MAX_DRAW_BUFFERS', 0x8824 )
GL_DRAW_BUFFER0 = constant.Constant( 'GL_DRAW_BUFFER0', 0x8825 )
GL_DRAW_BUFFER1 = constant.Constant( 'GL_DRAW_BUFFER1', 0x8826 )
GL_DRAW_BUFFER2 = constant.Constant( 'GL_DRAW_BUFFER2', 0x8827 )
GL_DRAW_BUFFER3 = constant.Constant( 'GL_DRAW_BUFFER3', 0x8828 )
GL_DRAW_BUFFER4 = constant.Constant( 'GL_DRAW_BUFFER4', 0x8829 )
GL_DRAW_BUFFER5 = constant.Constant( 'GL_DRAW_BUFFER5', 0x882A )
GL_DRAW_BUFFER6 = constant.Constant( 'GL_DRAW_BUFFER6', 0x882B )
GL_DRAW_BUFFER7 = constant.Constant( 'GL_DRAW_BUFFER7', 0x882C )
GL_DRAW_BUFFER8 = constant.Constant( 'GL_DRAW_BUFFER8', 0x882D )
GL_DRAW_BUFFER9 = constant.Constant( 'GL_DRAW_BUFFER9', 0x882E )
GL_DRAW_BUFFER10 = constant.Constant( 'GL_DRAW_BUFFER10', 0x882F )
GL_DRAW_BUFFER11 = constant.Constant( 'GL_DRAW_BUFFER11', 0x8830 )
GL_DRAW_BUFFER12 = constant.Constant( 'GL_DRAW_BUFFER12', 0x8831 )
GL_DRAW_BUFFER13 = constant.Constant( 'GL_DRAW_BUFFER13', 0x8832 )
GL_DRAW_BUFFER14 = constant.Constant( 'GL_DRAW_BUFFER14', 0x8833 )
GL_DRAW_BUFFER15 = constant.Constant( 'GL_DRAW_BUFFER15', 0x8834 )
GL_BLEND_EQUATION_ALPHA = constant.Constant( 'GL_BLEND_EQUATION_ALPHA', 0x883D )
GL_MAX_VERTEX_ATTRIBS = constant.Constant( 'GL_MAX_VERTEX_ATTRIBS', 0x8869 )
GL_VERTEX_ATTRIB_ARRAY_NORMALIZED = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_NORMALIZED', 0x886A )
GL_MAX_TEXTURE_IMAGE_UNITS = constant.Constant( 'GL_MAX_TEXTURE_IMAGE_UNITS', 0x8872 )
GL_FRAGMENT_SHADER = constant.Constant( 'GL_FRAGMENT_SHADER', 0x8B30 )
GL_VERTEX_SHADER = constant.Constant( 'GL_VERTEX_SHADER', 0x8B31 )
GL_MAX_FRAGMENT_UNIFORM_COMPONENTS = constant.Constant( 'GL_MAX_FRAGMENT_UNIFORM_COMPONENTS', 0x8B49 )
GL_MAX_VERTEX_UNIFORM_COMPONENTS = constant.Constant( 'GL_MAX_VERTEX_UNIFORM_COMPONENTS', 0x8B4A )
GL_MAX_VARYING_FLOATS = constant.Constant( 'GL_MAX_VARYING_FLOATS', 0x8B4B )
GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS = constant.Constant( 'GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS', 0x8B4C )
GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS = constant.Constant( 'GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS', 0x8B4D )
GL_SHADER_TYPE = constant.Constant( 'GL_SHADER_TYPE', 0x8B4F )
GL_FLOAT_VEC2 = constant.Constant( 'GL_FLOAT_VEC2', 0x8B50 )
GL_FLOAT_VEC3 = constant.Constant( 'GL_FLOAT_VEC3', 0x8B51 )
GL_FLOAT_VEC4 = constant.Constant( 'GL_FLOAT_VEC4', 0x8B52 )
GL_INT_VEC2 = constant.Constant( 'GL_INT_VEC2', 0x8B53 )
GL_INT_VEC3 = constant.Constant( 'GL_INT_VEC3', 0x8B54 )
GL_INT_VEC4 = constant.Constant( 'GL_INT_VEC4', 0x8B55 )
GL_BOOL = constant.Constant( 'GL_BOOL', 0x8B56 )
GL_BOOL_VEC2 = constant.Constant( 'GL_BOOL_VEC2', 0x8B57 )
GL_BOOL_VEC3 = constant.Constant( 'GL_BOOL_VEC3', 0x8B58 )
GL_BOOL_VEC4 = constant.Constant( 'GL_BOOL_VEC4', 0x8B59 )
GL_FLOAT_MAT2 = constant.Constant( 'GL_FLOAT_MAT2', 0x8B5A )
GL_FLOAT_MAT3 = constant.Constant( 'GL_FLOAT_MAT3', 0x8B5B )
GL_FLOAT_MAT4 = constant.Constant( 'GL_FLOAT_MAT4', 0x8B5C )
GL_SAMPLER_1D = constant.Constant( 'GL_SAMPLER_1D', 0x8B5D )
GL_SAMPLER_2D = constant.Constant( 'GL_SAMPLER_2D', 0x8B5E )
GL_SAMPLER_3D = constant.Constant( 'GL_SAMPLER_3D', 0x8B5F )
GL_SAMPLER_CUBE = constant.Constant( 'GL_SAMPLER_CUBE', 0x8B60 )
GL_SAMPLER_1D_SHADOW = constant.Constant( 'GL_SAMPLER_1D_SHADOW', 0x8B61 )
GL_SAMPLER_2D_SHADOW = constant.Constant( 'GL_SAMPLER_2D_SHADOW', 0x8B62 )
GL_DELETE_STATUS = constant.Constant( 'GL_DELETE_STATUS', 0x8B80 )
GL_COMPILE_STATUS = constant.Constant( 'GL_COMPILE_STATUS', 0x8B81 )
GL_LINK_STATUS = constant.Constant( 'GL_LINK_STATUS', 0x8B82 )
GL_VALIDATE_STATUS = constant.Constant( 'GL_VALIDATE_STATUS', 0x8B83 )
GL_INFO_LOG_LENGTH = constant.Constant( 'GL_INFO_LOG_LENGTH', 0x8B84 )
GL_ATTACHED_SHADERS = constant.Constant( 'GL_ATTACHED_SHADERS', 0x8B85 )
GL_ACTIVE_UNIFORMS = constant.Constant( 'GL_ACTIVE_UNIFORMS', 0x8B86 )
GL_ACTIVE_UNIFORM_MAX_LENGTH = constant.Constant( 'GL_ACTIVE_UNIFORM_MAX_LENGTH', 0x8B87 )
GL_SHADER_SOURCE_LENGTH = constant.Constant( 'GL_SHADER_SOURCE_LENGTH', 0x8B88 )
GL_ACTIVE_ATTRIBUTES = constant.Constant( 'GL_ACTIVE_ATTRIBUTES', 0x8B89 )
GL_ACTIVE_ATTRIBUTE_MAX_LENGTH = constant.Constant( 'GL_ACTIVE_ATTRIBUTE_MAX_LENGTH', 0x8B8A )
GL_FRAGMENT_SHADER_DERIVATIVE_HINT = constant.Constant( 'GL_FRAGMENT_SHADER_DERIVATIVE_HINT', 0x8B8B )
GL_SHADING_LANGUAGE_VERSION = constant.Constant( 'GL_SHADING_LANGUAGE_VERSION', 0x8B8C )
GL_CURRENT_PROGRAM = constant.Constant( 'GL_CURRENT_PROGRAM', 0x8B8D )
GL_POINT_SPRITE_COORD_ORIGIN = constant.Constant( 'GL_POINT_SPRITE_COORD_ORIGIN', 0x8CA0 )
GL_LOWER_LEFT = constant.Constant( 'GL_LOWER_LEFT', 0x8CA1 )
GL_UPPER_LEFT = constant.Constant( 'GL_UPPER_LEFT', 0x8CA2 )
GL_STENCIL_BACK_REF = constant.Constant( 'GL_STENCIL_BACK_REF', 0x8CA3 )
GL_STENCIL_BACK_VALUE_MASK = constant.Constant( 'GL_STENCIL_BACK_VALUE_MASK', 0x8CA4 )
GL_STENCIL_BACK_WRITEMASK = constant.Constant( 'GL_STENCIL_BACK_WRITEMASK', 0x8CA5 )
glBlendEquationSeparate = platform.createExtensionFunction( 
'glBlendEquationSeparate',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glBlendEquationSeparate(GLenum(modeRGB), GLenum(modeAlpha)) -> None',
argNames=('modeRGB','modeAlpha',),
deprecated=_DEPRECATED,
)

glDrawBuffers = platform.createExtensionFunction( 
'glDrawBuffers',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDrawBuffers(GLsizei(n), GLuintArray(bufs)) -> None',
argNames=('n','bufs',),
deprecated=_DEPRECATED,
)

glStencilOpSeparate = platform.createExtensionFunction( 
'glStencilOpSeparate',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,),
doc='glStencilOpSeparate(GLenum(face), GLenum(sfail), GLenum(dpfail), GLenum(dppass)) -> None',
argNames=('face','sfail','dpfail','dppass',),
deprecated=_DEPRECATED,
)

glStencilFuncSeparate = platform.createExtensionFunction( 
'glStencilFuncSeparate',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLint,constants.GLuint,),
doc='glStencilFuncSeparate(GLenum(frontfunc), GLenum(backfunc), GLint(ref), GLuint(mask)) -> None',
argNames=('frontfunc','backfunc','ref','mask',),
deprecated=_DEPRECATED,
)

glStencilMaskSeparate = platform.createExtensionFunction( 
'glStencilMaskSeparate',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glStencilMaskSeparate(GLenum(face), GLuint(mask)) -> None',
argNames=('face','mask',),
deprecated=_DEPRECATED,
)

glAttachShader = platform.createExtensionFunction( 
'glAttachShader',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,),
doc='glAttachShader(GLuint(program), GLuint(shader)) -> None',
argNames=('program','shader',),
deprecated=_DEPRECATED,
)

glBindAttribLocation = platform.createExtensionFunction( 
'glBindAttribLocation',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,arrays.GLcharArray,),
doc='glBindAttribLocation(GLuint(program), GLuint(index), GLcharArray(name)) -> None',
argNames=('program','index','name',),
deprecated=_DEPRECATED,
)

glCompileShader = platform.createExtensionFunction( 
'glCompileShader',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glCompileShader(GLuint(shader)) -> None',
argNames=('shader',),
deprecated=_DEPRECATED,
)

glCreateProgram = platform.createExtensionFunction( 
'glCreateProgram',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLuint, 
argTypes=(),
doc='glCreateProgram() -> constants.GLuint',
argNames=(),
deprecated=_DEPRECATED,
)

glCreateShader = platform.createExtensionFunction( 
'glCreateShader',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLuint, 
argTypes=(constants.GLenum,),
doc='glCreateShader(GLenum(type)) -> constants.GLuint',
argNames=('type',),
deprecated=_DEPRECATED,
)

glDeleteProgram = platform.createExtensionFunction( 
'glDeleteProgram',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glDeleteProgram(GLuint(program)) -> None',
argNames=('program',),
deprecated=_DEPRECATED,
)

glDeleteShader = platform.createExtensionFunction( 
'glDeleteShader',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glDeleteShader(GLuint(shader)) -> None',
argNames=('shader',),
deprecated=_DEPRECATED,
)

glDetachShader = platform.createExtensionFunction( 
'glDetachShader',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,),
doc='glDetachShader(GLuint(program), GLuint(shader)) -> None',
argNames=('program','shader',),
deprecated=_DEPRECATED,
)

glDisableVertexAttribArray = platform.createExtensionFunction( 
'glDisableVertexAttribArray',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glDisableVertexAttribArray(GLuint(index)) -> None',
argNames=('index',),
deprecated=_DEPRECATED,
)

glEnableVertexAttribArray = platform.createExtensionFunction( 
'glEnableVertexAttribArray',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glEnableVertexAttribArray(GLuint(index)) -> None',
argNames=('index',),
deprecated=_DEPRECATED,
)

glGetActiveAttrib = platform.createExtensionFunction( 
'glGetActiveAttrib',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLsizei,arrays.GLsizeiArray,arrays.GLintArray,arrays.GLuintArray,arrays.GLcharArray,),
doc='glGetActiveAttrib(GLuint(program), GLuint(index), GLsizei(bufSize), GLsizeiArray(length), GLintArray(size), GLuintArray(type), GLcharArray(name)) -> None',
argNames=('program','index','bufSize','length','size','type','name',),
deprecated=_DEPRECATED,
)

glGetActiveUniform = platform.createExtensionFunction( 
'glGetActiveUniform',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLsizei,arrays.GLsizeiArray,arrays.GLintArray,arrays.GLuintArray,arrays.GLcharArray,),
doc='glGetActiveUniform(GLuint(program), GLuint(index), GLsizei(bufSize), GLsizeiArray(length), GLintArray(size), GLuintArray(type), GLcharArray(name)) -> None',
argNames=('program','index','bufSize','length','size','type','name',),
deprecated=_DEPRECATED,
)

glGetAttachedShaders = platform.createExtensionFunction( 
'glGetAttachedShaders',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLsizeiArray,arrays.GLuintArray,),
doc='glGetAttachedShaders(GLuint(program), GLsizei(maxCount), GLsizeiArray(count), GLuintArray(obj)) -> None',
argNames=('program','maxCount','count','obj',),
deprecated=_DEPRECATED,
)

glGetAttribLocation = platform.createExtensionFunction( 
'glGetAttribLocation',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLint, 
argTypes=(constants.GLuint,arrays.GLcharArray,),
doc='glGetAttribLocation(GLuint(program), GLcharArray(name)) -> constants.GLint',
argNames=('program','name',),
deprecated=_DEPRECATED,
)

glGetProgramiv = platform.createExtensionFunction( 
'glGetProgramiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetProgramiv(GLuint(program), GLenum(pname), GLintArray(params)) -> None',
argNames=('program','pname','params',),
deprecated=_DEPRECATED,
)

glGetProgramInfoLog = platform.createExtensionFunction( 
'glGetProgramInfoLog',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray,),
doc='glGetProgramInfoLog(GLuint(program), GLsizei(bufSize), GLsizeiArray(length), GLcharArray(infoLog)) -> None',
argNames=('program','bufSize','length','infoLog',),
deprecated=_DEPRECATED,
)

glGetShaderiv = platform.createExtensionFunction( 
'glGetShaderiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetShaderiv(GLuint(shader), GLenum(pname), GLintArray(params)) -> None',
argNames=('shader','pname','params',),
deprecated=_DEPRECATED,
)

glGetShaderInfoLog = platform.createExtensionFunction( 
'glGetShaderInfoLog',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray,),
doc='glGetShaderInfoLog(GLuint(shader), GLsizei(bufSize), GLsizeiArray(length), GLcharArray(infoLog)) -> None',
argNames=('shader','bufSize','length','infoLog',),
deprecated=_DEPRECATED,
)

glGetShaderSource = platform.createExtensionFunction( 
'glGetShaderSource',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray,),
doc='glGetShaderSource(GLuint(shader), GLsizei(bufSize), GLsizeiArray(length), GLcharArray(source)) -> None',
argNames=('shader','bufSize','length','source',),
deprecated=_DEPRECATED,
)

glGetUniformLocation = platform.createExtensionFunction( 
'glGetUniformLocation',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLint, 
argTypes=(constants.GLuint,arrays.GLcharArray,),
doc='glGetUniformLocation(GLuint(program), GLcharArray(name)) -> constants.GLint',
argNames=('program','name',),
deprecated=_DEPRECATED,
)

glGetUniformfv = platform.createExtensionFunction( 
'glGetUniformfv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,arrays.GLfloatArray,),
doc='glGetUniformfv(GLuint(program), GLint(location), GLfloatArray(params)) -> None',
argNames=('program','location','params',),
deprecated=_DEPRECATED,
)

glGetUniformiv = platform.createExtensionFunction( 
'glGetUniformiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,arrays.GLintArray,),
doc='glGetUniformiv(GLuint(program), GLint(location), GLintArray(params)) -> None',
argNames=('program','location','params',),
deprecated=_DEPRECATED,
)

glGetVertexAttribdv = platform.createExtensionFunction( 
'glGetVertexAttribdv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLdoubleArray,),
doc='glGetVertexAttribdv(GLuint(index), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('index','pname','params',),
deprecated=_DEPRECATED,
)

glGetVertexAttribfv = platform.createExtensionFunction( 
'glGetVertexAttribfv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetVertexAttribfv(GLuint(index), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('index','pname','params',),
deprecated=_DEPRECATED,
)

glGetVertexAttribiv = platform.createExtensionFunction( 
'glGetVertexAttribiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetVertexAttribiv(GLuint(index), GLenum(pname), GLintArray(params)) -> None',
argNames=('index','pname','params',),
deprecated=_DEPRECATED,
)

glGetVertexAttribPointerv = platform.createExtensionFunction( 
'glGetVertexAttribPointerv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,ctypes.POINTER(ctypes.c_void_p),),
doc='glGetVertexAttribPointerv(GLuint(index), GLenum(pname), POINTER(ctypes.c_void_p)(pointer)) -> None',
argNames=('index','pname','pointer',),
deprecated=_DEPRECATED,
)

glIsProgram = platform.createExtensionFunction( 
'glIsProgram',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsProgram(GLuint(program)) -> constants.GLboolean',
argNames=('program',),
deprecated=_DEPRECATED,
)

glIsShader = platform.createExtensionFunction( 
'glIsShader',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsShader(GLuint(shader)) -> constants.GLboolean',
argNames=('shader',),
deprecated=_DEPRECATED,
)

glLinkProgram = platform.createExtensionFunction( 
'glLinkProgram',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glLinkProgram(GLuint(program)) -> None',
argNames=('program',),
deprecated=_DEPRECATED,
)

glShaderSource = platform.createExtensionFunction( 
'glShaderSource',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,ctypes.POINTER( ctypes.POINTER( constants.GLchar )),arrays.GLintArray,),
doc='glShaderSource(GLuint(shader), GLsizei(count), POINTER( ctypes.POINTER( constants.GLchar ))(string), GLintArray(length)) -> None',
argNames=('shader','count','string','length',),
deprecated=_DEPRECATED,
)

glUseProgram = platform.createExtensionFunction( 
'glUseProgram',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glUseProgram(GLuint(program)) -> None',
argNames=('program',),
deprecated=_DEPRECATED,
)

glUniform1f = platform.createExtensionFunction( 
'glUniform1f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLfloat,),
doc='glUniform1f(GLint(location), GLfloat(v0)) -> None',
argNames=('location','v0',),
deprecated=_DEPRECATED,
)

glUniform2f = platform.createExtensionFunction( 
'glUniform2f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLfloat,constants.GLfloat,),
doc='glUniform2f(GLint(location), GLfloat(v0), GLfloat(v1)) -> None',
argNames=('location','v0','v1',),
deprecated=_DEPRECATED,
)

glUniform3f = platform.createExtensionFunction( 
'glUniform3f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glUniform3f(GLint(location), GLfloat(v0), GLfloat(v1), GLfloat(v2)) -> None',
argNames=('location','v0','v1','v2',),
deprecated=_DEPRECATED,
)

glUniform4f = platform.createExtensionFunction( 
'glUniform4f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glUniform4f(GLint(location), GLfloat(v0), GLfloat(v1), GLfloat(v2), GLfloat(v3)) -> None',
argNames=('location','v0','v1','v2','v3',),
deprecated=_DEPRECATED,
)

glUniform1i = platform.createExtensionFunction( 
'glUniform1i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,),
doc='glUniform1i(GLint(location), GLint(v0)) -> None',
argNames=('location','v0',),
deprecated=_DEPRECATED,
)

glUniform2i = platform.createExtensionFunction( 
'glUniform2i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,constants.GLint,),
doc='glUniform2i(GLint(location), GLint(v0), GLint(v1)) -> None',
argNames=('location','v0','v1',),
deprecated=_DEPRECATED,
)

glUniform3i = platform.createExtensionFunction( 
'glUniform3i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glUniform3i(GLint(location), GLint(v0), GLint(v1), GLint(v2)) -> None',
argNames=('location','v0','v1','v2',),
deprecated=_DEPRECATED,
)

glUniform4i = platform.createExtensionFunction( 
'glUniform4i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glUniform4i(GLint(location), GLint(v0), GLint(v1), GLint(v2), GLint(v3)) -> None',
argNames=('location','v0','v1','v2','v3',),
deprecated=_DEPRECATED,
)

glUniform1fv = platform.createExtensionFunction( 
'glUniform1fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glUniform1fv(GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform2fv = platform.createExtensionFunction( 
'glUniform2fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glUniform2fv(GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform3fv = platform.createExtensionFunction( 
'glUniform3fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glUniform3fv(GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform4fv = platform.createExtensionFunction( 
'glUniform4fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLfloatArray,),
doc='glUniform4fv(GLint(location), GLsizei(count), GLfloatArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform1iv = platform.createExtensionFunction( 
'glUniform1iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glUniform1iv(GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform2iv = platform.createExtensionFunction( 
'glUniform2iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glUniform2iv(GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform3iv = platform.createExtensionFunction( 
'glUniform3iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glUniform3iv(GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform4iv = platform.createExtensionFunction( 
'glUniform4iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLintArray,),
doc='glUniform4iv(GLint(location), GLsizei(count), GLintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniformMatrix2fv = platform.createExtensionFunction( 
'glUniformMatrix2fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glUniformMatrix2fv(GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glUniformMatrix3fv = platform.createExtensionFunction( 
'glUniformMatrix3fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glUniformMatrix3fv(GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glUniformMatrix4fv = platform.createExtensionFunction( 
'glUniformMatrix4fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,constants.GLboolean,arrays.GLfloatArray,),
doc='glUniformMatrix4fv(GLint(location), GLsizei(count), GLboolean(transpose), GLfloatArray(value)) -> None',
argNames=('location','count','transpose','value',),
deprecated=_DEPRECATED,
)

glValidateProgram = platform.createExtensionFunction( 
'glValidateProgram',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glValidateProgram(GLuint(program)) -> None',
argNames=('program',),
deprecated=_DEPRECATED,
)

glVertexAttrib1d = platform.createExtensionFunction( 
'glVertexAttrib1d',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLdouble,),
doc='glVertexAttrib1d(GLuint(index), GLdouble(x)) -> None',
argNames=('index','x',),
deprecated=_DEPRECATED,
)

glVertexAttrib1dv = platform.createExtensionFunction( 
'glVertexAttrib1dv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLdoubleArray,),
doc='glVertexAttrib1dv(GLuint(index), GLdoubleArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib1f = platform.createExtensionFunction( 
'glVertexAttrib1f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,),
doc='glVertexAttrib1f(GLuint(index), GLfloat(x)) -> None',
argNames=('index','x',),
deprecated=_DEPRECATED,
)

glVertexAttrib1fv = platform.createExtensionFunction( 
'glVertexAttrib1fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLfloatArray,),
doc='glVertexAttrib1fv(GLuint(index), GLfloatArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib1s = platform.createExtensionFunction( 
'glVertexAttrib1s',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLshort,),
doc='glVertexAttrib1s(GLuint(index), GLshort(x)) -> None',
argNames=('index','x',),
deprecated=_DEPRECATED,
)

glVertexAttrib1sv = platform.createExtensionFunction( 
'glVertexAttrib1sv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVertexAttrib1sv(GLuint(index), GLshortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib2d = platform.createExtensionFunction( 
'glVertexAttrib2d',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLdouble,constants.GLdouble,),
doc='glVertexAttrib2d(GLuint(index), GLdouble(x), GLdouble(y)) -> None',
argNames=('index','x','y',),
deprecated=_DEPRECATED,
)

glVertexAttrib2dv = platform.createExtensionFunction( 
'glVertexAttrib2dv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLdoubleArray,),
doc='glVertexAttrib2dv(GLuint(index), GLdoubleArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib2f = platform.createExtensionFunction( 
'glVertexAttrib2f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,),
doc='glVertexAttrib2f(GLuint(index), GLfloat(x), GLfloat(y)) -> None',
argNames=('index','x','y',),
deprecated=_DEPRECATED,
)

glVertexAttrib2fv = platform.createExtensionFunction( 
'glVertexAttrib2fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLfloatArray,),
doc='glVertexAttrib2fv(GLuint(index), GLfloatArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib2s = platform.createExtensionFunction( 
'glVertexAttrib2s',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLshort,constants.GLshort,),
doc='glVertexAttrib2s(GLuint(index), GLshort(x), GLshort(y)) -> None',
argNames=('index','x','y',),
deprecated=_DEPRECATED,
)

glVertexAttrib2sv = platform.createExtensionFunction( 
'glVertexAttrib2sv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVertexAttrib2sv(GLuint(index), GLshortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib3d = platform.createExtensionFunction( 
'glVertexAttrib3d',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glVertexAttrib3d(GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z)) -> None',
argNames=('index','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexAttrib3dv = platform.createExtensionFunction( 
'glVertexAttrib3dv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLdoubleArray,),
doc='glVertexAttrib3dv(GLuint(index), GLdoubleArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib3f = platform.createExtensionFunction( 
'glVertexAttrib3f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glVertexAttrib3f(GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('index','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexAttrib3fv = platform.createExtensionFunction( 
'glVertexAttrib3fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLfloatArray,),
doc='glVertexAttrib3fv(GLuint(index), GLfloatArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib3s = platform.createExtensionFunction( 
'glVertexAttrib3s',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glVertexAttrib3s(GLuint(index), GLshort(x), GLshort(y), GLshort(z)) -> None',
argNames=('index','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexAttrib3sv = platform.createExtensionFunction( 
'glVertexAttrib3sv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVertexAttrib3sv(GLuint(index), GLshortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4Nbv = platform.createExtensionFunction( 
'glVertexAttrib4Nbv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLbyteArray,),
doc='glVertexAttrib4Nbv(GLuint(index), GLbyteArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4Niv = platform.createExtensionFunction( 
'glVertexAttrib4Niv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLintArray,),
doc='glVertexAttrib4Niv(GLuint(index), GLintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4Nsv = platform.createExtensionFunction( 
'glVertexAttrib4Nsv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVertexAttrib4Nsv(GLuint(index), GLshortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4Nub = platform.createExtensionFunction( 
'glVertexAttrib4Nub',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLubyte,constants.GLubyte,constants.GLubyte,constants.GLubyte,),
doc='glVertexAttrib4Nub(GLuint(index), GLubyte(x), GLubyte(y), GLubyte(z), GLubyte(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttrib4Nubv = platform.createExtensionFunction( 
'glVertexAttrib4Nubv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLubyteArray,),
doc='glVertexAttrib4Nubv(GLuint(index), GLubyteArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4Nuiv = platform.createExtensionFunction( 
'glVertexAttrib4Nuiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLuintArray,),
doc='glVertexAttrib4Nuiv(GLuint(index), GLuintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4Nusv = platform.createExtensionFunction( 
'glVertexAttrib4Nusv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLushortArray,),
doc='glVertexAttrib4Nusv(GLuint(index), GLushortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4bv = platform.createExtensionFunction( 
'glVertexAttrib4bv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLbyteArray,),
doc='glVertexAttrib4bv(GLuint(index), GLbyteArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4d = platform.createExtensionFunction( 
'glVertexAttrib4d',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glVertexAttrib4d(GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttrib4dv = platform.createExtensionFunction( 
'glVertexAttrib4dv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLdoubleArray,),
doc='glVertexAttrib4dv(GLuint(index), GLdoubleArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4f = platform.createExtensionFunction( 
'glVertexAttrib4f',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glVertexAttrib4f(GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttrib4fv = platform.createExtensionFunction( 
'glVertexAttrib4fv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLfloatArray,),
doc='glVertexAttrib4fv(GLuint(index), GLfloatArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4iv = platform.createExtensionFunction( 
'glVertexAttrib4iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLintArray,),
doc='glVertexAttrib4iv(GLuint(index), GLintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4s = platform.createExtensionFunction( 
'glVertexAttrib4s',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLshort,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glVertexAttrib4s(GLuint(index), GLshort(x), GLshort(y), GLshort(z), GLshort(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttrib4sv = platform.createExtensionFunction( 
'glVertexAttrib4sv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVertexAttrib4sv(GLuint(index), GLshortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4ubv = platform.createExtensionFunction( 
'glVertexAttrib4ubv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLubyteArray,),
doc='glVertexAttrib4ubv(GLuint(index), GLubyteArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4uiv = platform.createExtensionFunction( 
'glVertexAttrib4uiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLuintArray,),
doc='glVertexAttrib4uiv(GLuint(index), GLuintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4usv = platform.createExtensionFunction( 
'glVertexAttrib4usv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLushortArray,),
doc='glVertexAttrib4usv(GLuint(index), GLushortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribPointer = platform.createExtensionFunction( 
'glVertexAttribPointer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLenum,constants.GLboolean,constants.GLsizei,ctypes.c_void_p,),
doc='glVertexAttribPointer(GLuint(index), GLint(size), GLenum(type), GLboolean(normalized), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('index','size','type','normalized','stride','pointer',),
deprecated=_DEPRECATED,
)
# import legacy entry points to allow checking for bool(entryPoint)
from OpenGL.raw.GL.VERSION.GL_2_0_DEPRECATED import *



"""Module to provide numeric-module name for current version"""
def moduleName( module ):
    """Given a numpy, numeric or numarray module, calculate helper module name"""
    name = module.__name__.lower()
    version = '_'.join( module.__version__.split('.'))
    return 'OpenGL.arrays._%(name)s_%(version)s'%locals()
def loadModule( name ):
    """Load the current C module for our numeric version"""
    return __import__( name, {}, {}, name.split( '.' ))


'''OpenGL extension NV.framebuffer_multisample_coverage

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_framebuffer_multisample_coverage'
_DEPRECATED = False
GL_RENDERBUFFER_COVERAGE_SAMPLES_NV = constant.Constant( 'GL_RENDERBUFFER_COVERAGE_SAMPLES_NV', 0x8CAB )
GL_RENDERBUFFER_COLOR_SAMPLES_NV = constant.Constant( 'GL_RENDERBUFFER_COLOR_SAMPLES_NV', 0x8E10 )
GL_MAX_MULTISAMPLE_COVERAGE_MODES_NV = constant.Constant( 'GL_MAX_MULTISAMPLE_COVERAGE_MODES_NV', 0x8E11 )
glget.addGLGetConstant( GL_MAX_MULTISAMPLE_COVERAGE_MODES_NV, (1,) )
GL_MULTISAMPLE_COVERAGE_MODES_NV = constant.Constant( 'GL_MULTISAMPLE_COVERAGE_MODES_NV', 0x8E12 )
glRenderbufferStorageMultisampleCoverageNV = platform.createExtensionFunction( 
'glRenderbufferStorageMultisampleCoverageNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,constants.GLsizei,),
doc='glRenderbufferStorageMultisampleCoverageNV(GLenum(target), GLsizei(coverageSamples), GLsizei(colorSamples), GLenum(internalformat), GLsizei(width), GLsizei(height)) -> None',
argNames=('target','coverageSamples','colorSamples','internalformat','width','height',),
deprecated=_DEPRECATED,
)


def glInitFramebufferMultisampleCoverageNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.cull_vertex

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_cull_vertex'
_DEPRECATED = False
GL_CULL_VERTEX_EXT = constant.Constant( 'GL_CULL_VERTEX_EXT', 0x81AA )
GL_CULL_VERTEX_EYE_POSITION_EXT = constant.Constant( 'GL_CULL_VERTEX_EYE_POSITION_EXT', 0x81AB )
GL_CULL_VERTEX_OBJECT_POSITION_EXT = constant.Constant( 'GL_CULL_VERTEX_OBJECT_POSITION_EXT', 0x81AC )
glCullParameterdvEXT = platform.createExtensionFunction( 
'glCullParameterdvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glCullParameterdvEXT(GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)

glCullParameterfvEXT = platform.createExtensionFunction( 
'glCullParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glCullParameterfvEXT(GLenum(pname), GLfloatArray(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)


def glInitCullVertexEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIS.texture_select

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_texture_select'
_DEPRECATED = False
GL_DUAL_ALPHA4_SGIS = constant.Constant( 'GL_DUAL_ALPHA4_SGIS', 0x8110 )
GL_DUAL_ALPHA8_SGIS = constant.Constant( 'GL_DUAL_ALPHA8_SGIS', 0x8111 )
GL_DUAL_ALPHA12_SGIS = constant.Constant( 'GL_DUAL_ALPHA12_SGIS', 0x8112 )
GL_DUAL_ALPHA16_SGIS = constant.Constant( 'GL_DUAL_ALPHA16_SGIS', 0x8113 )
GL_DUAL_LUMINANCE4_SGIS = constant.Constant( 'GL_DUAL_LUMINANCE4_SGIS', 0x8114 )
GL_DUAL_LUMINANCE8_SGIS = constant.Constant( 'GL_DUAL_LUMINANCE8_SGIS', 0x8115 )
GL_DUAL_LUMINANCE12_SGIS = constant.Constant( 'GL_DUAL_LUMINANCE12_SGIS', 0x8116 )
GL_DUAL_LUMINANCE16_SGIS = constant.Constant( 'GL_DUAL_LUMINANCE16_SGIS', 0x8117 )
GL_DUAL_INTENSITY4_SGIS = constant.Constant( 'GL_DUAL_INTENSITY4_SGIS', 0x8118 )
GL_DUAL_INTENSITY8_SGIS = constant.Constant( 'GL_DUAL_INTENSITY8_SGIS', 0x8119 )
GL_DUAL_INTENSITY12_SGIS = constant.Constant( 'GL_DUAL_INTENSITY12_SGIS', 0x811A )
GL_DUAL_INTENSITY16_SGIS = constant.Constant( 'GL_DUAL_INTENSITY16_SGIS', 0x811B )
GL_DUAL_LUMINANCE_ALPHA4_SGIS = constant.Constant( 'GL_DUAL_LUMINANCE_ALPHA4_SGIS', 0x811C )
GL_DUAL_LUMINANCE_ALPHA8_SGIS = constant.Constant( 'GL_DUAL_LUMINANCE_ALPHA8_SGIS', 0x811D )
GL_QUAD_ALPHA4_SGIS = constant.Constant( 'GL_QUAD_ALPHA4_SGIS', 0x811E )
GL_QUAD_ALPHA8_SGIS = constant.Constant( 'GL_QUAD_ALPHA8_SGIS', 0x811F )
GL_QUAD_LUMINANCE4_SGIS = constant.Constant( 'GL_QUAD_LUMINANCE4_SGIS', 0x8120 )
GL_QUAD_LUMINANCE8_SGIS = constant.Constant( 'GL_QUAD_LUMINANCE8_SGIS', 0x8121 )
GL_QUAD_INTENSITY4_SGIS = constant.Constant( 'GL_QUAD_INTENSITY4_SGIS', 0x8122 )
GL_QUAD_INTENSITY8_SGIS = constant.Constant( 'GL_QUAD_INTENSITY8_SGIS', 0x8123 )
GL_DUAL_TEXTURE_SELECT_SGIS = constant.Constant( 'GL_DUAL_TEXTURE_SELECT_SGIS', 0x8124 )
GL_QUAD_TEXTURE_SELECT_SGIS = constant.Constant( 'GL_QUAD_TEXTURE_SELECT_SGIS', 0x8125 )


def glInitTextureSelectSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIS.sharpen_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_sharpen_texture'
_DEPRECATED = False
GL_LINEAR_SHARPEN_SGIS = constant.Constant( 'GL_LINEAR_SHARPEN_SGIS', 0x80AD )
GL_LINEAR_SHARPEN_ALPHA_SGIS = constant.Constant( 'GL_LINEAR_SHARPEN_ALPHA_SGIS', 0x80AE )
GL_LINEAR_SHARPEN_COLOR_SGIS = constant.Constant( 'GL_LINEAR_SHARPEN_COLOR_SGIS', 0x80AF )
GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS = constant.Constant( 'GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS', 0x80B0 )
glSharpenTexFuncSGIS = platform.createExtensionFunction( 
'glSharpenTexFuncSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,arrays.GLfloatArray,),
doc='glSharpenTexFuncSGIS(GLenum(target), GLsizei(n), GLfloatArray(points)) -> None',
argNames=('target','n','points',),
deprecated=_DEPRECATED,
)

glGetSharpenTexFuncSGIS = platform.createExtensionFunction( 
'glGetSharpenTexFuncSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glGetSharpenTexFuncSGIS(GLenum(target), GLfloatArray(points)) -> None',
argNames=('target','points',),
deprecated=_DEPRECATED,
)


def glInitSharpenTextureSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



#! /usr/bin/env python
from OpenGL.GLUT import *

delay = 1
count = 0

def timerCallback(value):
    global count
    count += 1
    if count % 2000 == 0: print count
    glutTimerFunc( delay, timerCallback, value+1 )

if __name__ == "__main__":
    glutInit( sys.argv )
    glutInitDisplayMode( GLUT_DOUBLE | GLUT_RGBA | GLUT_DEPTH )
    glutInitWindowSize( 100, 100 )
    glutCreateWindow( "testtimer" )

    glutTimerFunc( delay, timerCallback, 0 )

    glutMainLoop()


'''OpenGL extension SGIS.multisample

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism to antialias all GL primitives:
	points, lines, polygons, bitmaps, and images.  The technique is to
	sample all primitives multiple times at each pixel.  The color sample
	values are resolved to a single, displayable color each time a pixel
	is updated, so the antialiasing appears to be automatic at the
	application level.  Because each sample includes depth and stencil
	information, the depth and stencil functions perform equivalently
	to the single-sample mode.
	
	An additional buffer, called the multisample buffer, is added to
	the framebuffer.  Pixel sample values, including color, depth, and
	stencil values, are stored in this buffer.  When the framebuffer
	includes a multisample buffer, it does not also include separate
	depth or stencil buffers, even if the multisample buffer does not
	store depth or stencil values.  Color buffers (left/right, front/
	back, and aux) do coexist with the multisample buffer, however.
	
	Multisample antialiasing is most valuable for rendering polygons,
	because it requires no sorting for hidden surface elimination, and
	it correctly handles adjacent polygons, object silhouettes, and
	even intersecting polygons.  If only points or lines are being
	rendered, the "smooth" antialiasing mechanism provided by the base
	GL may result in a higher quality image.  This extension is designed
	to allow multisample and smooth antialiasing techniques to be
	alternated during the rendering of a single scene.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/multisample.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.SGIS.multisample import *
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.multi_draw_arrays

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.multi_draw_arrays to provide a more 
Python-friendly API

Overview (from the spec)
	
	These functions behave identically to the standard OpenGL 1.1 functions
	glDrawArrays() and glDrawElements() except they handle multiple lists of
	vertices in one call. Their main purpose is to allow one function call
	to render more than one primitive such as triangle strip, triangle fan,
	etc.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/multi_draw_arrays.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.multi_draw_arrays import *
### END AUTOGENERATED SECTION
from OpenGL.lazywrapper import lazy
from OpenGL.GL.pointers import glDrawElements

@lazy( glMultiDrawElementsEXT )
def glMultiDrawElementsEXT(baseOperation, primtype, counts, typ, indices, primcount=None):
    """Currently glMultiDrawElementsEXT is not working in the wrapper 
    
    We are replacing the code with a sequence of glDrawElements calls
    as per the spec for the function.  Basically we'd spend more effort
    making an array of array pointers than we would creating a simple
    iteration in Python.
    """
    if primcount is not None:
        for i in xrange( primcount ):
            glDrawElements( primtype, counts[i], typ, indices[i] )
    else:
        for c,i in zip( counts, indices ):
            glDrawElements( primtype, c, typ, i )

#def convertIndices( arg, wrappedOperation, args ):
#	"""Convert indices to an array of arrays"""
#	return [
#		arrays.ArrayDatatype.asArray( element, args[2] )
#		for element in arg
#	]
#def resolveIndices( value ):
#	pointers = []
#	for v in value:
#		pointers.append( arrays.ArrayDatatype.voidDataPointer( v ) )
#	typ = ctypes.POINTER(None) * len(value)
#	return typ( *pointers )
#
#glMultiDrawElementsEXT = wrapper.wrapper( glMultiDrawElementsEXT ).setPyConverter(
#	'indices', convertIndices,
#).setCResolver( 
#	'indices', resolveIndices,
#).setPyConverter(
#	'count', arrays.AsArrayTyped( 'count', arrays.GLsizeiArray ),
#).setCResolver(
#	'count', arrays.ArrayDatatype.voidDataPointer ,
#)


'''OpenGL extension EXT.shadow_funcs

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.shadow_funcs to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension generalizes the GL_ARB_shadow extension to support all
	eight binary texture comparison functions rather than just GL_LEQUAL
	and GL_GEQUAL.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/shadow_funcs.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.shadow_funcs import *
### END AUTOGENERATED SECTION


'''OpenGL extension SGIS.fog_function

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_fog_function'
_DEPRECATED = False
GL_FOG_FUNC_SGIS = constant.Constant( 'GL_FOG_FUNC_SGIS', 0x812A )
GL_FOG_FUNC_POINTS_SGIS = constant.Constant( 'GL_FOG_FUNC_POINTS_SGIS', 0x812B )
GL_MAX_FOG_FUNC_POINTS_SGIS = constant.Constant( 'GL_MAX_FOG_FUNC_POINTS_SGIS', 0x812C )
glFogFuncSGIS = platform.createExtensionFunction( 
'glFogFuncSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLfloatArray,),
doc='glFogFuncSGIS(GLsizei(n), GLfloatArray(points)) -> None',
argNames=('n','points',),
deprecated=_DEPRECATED,
)

glGetFogFuncSGIS = platform.createExtensionFunction( 
'glGetFogFuncSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glGetFogFuncSGIS(GLfloatArray(points)) -> None',
argNames=('points',),
deprecated=_DEPRECATED,
)


def glInitFogFunctionSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension IBM.rasterpos_clip

This module customises the behaviour of the 
OpenGL.raw.GL.IBM.rasterpos_clip to provide a more 
Python-friendly API

Overview (from the spec)
	
	IBM_rasterpos_clip extends the semantics of the RasterPos functions.  It
	provides an enable that allows a raster position that would normally be
	clipped to be treated as a valid (albeit out-of-viewport) position.
	
	This extension allows applications to specify geometry-aligned pixel
	primitives that may be partially off-screen.  These primitives are
	tested on a pixel-by-pixel basis without being rejected completely
	because of an invalid raster position.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/IBM/rasterpos_clip.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.IBM.rasterpos_clip import *
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.color_buffer_float

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_color_buffer_float'
_DEPRECATED = False
GL_RGBA_FLOAT_MODE_ARB = constant.Constant( 'GL_RGBA_FLOAT_MODE_ARB', 0x8820 )
glget.addGLGetConstant( GL_RGBA_FLOAT_MODE_ARB, (1,) )
GL_CLAMP_VERTEX_COLOR_ARB = constant.Constant( 'GL_CLAMP_VERTEX_COLOR_ARB', 0x891A )
glget.addGLGetConstant( GL_CLAMP_VERTEX_COLOR_ARB, (1,) )
GL_CLAMP_FRAGMENT_COLOR_ARB = constant.Constant( 'GL_CLAMP_FRAGMENT_COLOR_ARB', 0x891B )
glget.addGLGetConstant( GL_CLAMP_FRAGMENT_COLOR_ARB, (1,) )
GL_CLAMP_READ_COLOR_ARB = constant.Constant( 'GL_CLAMP_READ_COLOR_ARB', 0x891C )
glget.addGLGetConstant( GL_CLAMP_READ_COLOR_ARB, (1,) )
GL_FIXED_ONLY_ARB = constant.Constant( 'GL_FIXED_ONLY_ARB', 0x891D )
glClampColorARB = platform.createExtensionFunction( 
'glClampColorARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glClampColorARB(GLenum(target), GLenum(clamp)) -> None',
argNames=('target','clamp',),
deprecated=_DEPRECATED,
)


def glInitColorBufferFloatARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.vertex_blend

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_vertex_blend'
_DEPRECATED = False
GL_MAX_VERTEX_UNITS_ARB = constant.Constant( 'GL_MAX_VERTEX_UNITS_ARB', 0x86A4 )
glget.addGLGetConstant( GL_MAX_VERTEX_UNITS_ARB, (1,) )
GL_ACTIVE_VERTEX_UNITS_ARB = constant.Constant( 'GL_ACTIVE_VERTEX_UNITS_ARB', 0x86A5 )
glget.addGLGetConstant( GL_ACTIVE_VERTEX_UNITS_ARB, (1,) )
GL_WEIGHT_SUM_UNITY_ARB = constant.Constant( 'GL_WEIGHT_SUM_UNITY_ARB', 0x86A6 )
glget.addGLGetConstant( GL_WEIGHT_SUM_UNITY_ARB, (1,) )
GL_VERTEX_BLEND_ARB = constant.Constant( 'GL_VERTEX_BLEND_ARB', 0x86A7 )
glget.addGLGetConstant( GL_VERTEX_BLEND_ARB, (1,) )
GL_CURRENT_WEIGHT_ARB = constant.Constant( 'GL_CURRENT_WEIGHT_ARB', 0x86A8 )
glget.addGLGetConstant( GL_CURRENT_WEIGHT_ARB, (1,) )
GL_WEIGHT_ARRAY_TYPE_ARB = constant.Constant( 'GL_WEIGHT_ARRAY_TYPE_ARB', 0x86A9 )
glget.addGLGetConstant( GL_WEIGHT_ARRAY_TYPE_ARB, (1,) )
GL_WEIGHT_ARRAY_STRIDE_ARB = constant.Constant( 'GL_WEIGHT_ARRAY_STRIDE_ARB', 0x86AA )
glget.addGLGetConstant( GL_WEIGHT_ARRAY_STRIDE_ARB, (1,) )
GL_WEIGHT_ARRAY_SIZE_ARB = constant.Constant( 'GL_WEIGHT_ARRAY_SIZE_ARB', 0x86AB )
glget.addGLGetConstant( GL_WEIGHT_ARRAY_SIZE_ARB, (1,) )
GL_WEIGHT_ARRAY_POINTER_ARB = constant.Constant( 'GL_WEIGHT_ARRAY_POINTER_ARB', 0x86AC )
GL_WEIGHT_ARRAY_ARB = constant.Constant( 'GL_WEIGHT_ARRAY_ARB', 0x86AD )
GL_MODELVIEW0_ARB = constant.Constant( 'GL_MODELVIEW0_ARB', 0x1700 )
GL_MODELVIEW1_ARB = constant.Constant( 'GL_MODELVIEW1_ARB', 0x850A )
GL_MODELVIEW2_ARB = constant.Constant( 'GL_MODELVIEW2_ARB', 0x8722 )
GL_MODELVIEW3_ARB = constant.Constant( 'GL_MODELVIEW3_ARB', 0x8723 )
GL_MODELVIEW4_ARB = constant.Constant( 'GL_MODELVIEW4_ARB', 0x8724 )
GL_MODELVIEW5_ARB = constant.Constant( 'GL_MODELVIEW5_ARB', 0x8725 )
GL_MODELVIEW6_ARB = constant.Constant( 'GL_MODELVIEW6_ARB', 0x8726 )
GL_MODELVIEW7_ARB = constant.Constant( 'GL_MODELVIEW7_ARB', 0x8727 )
GL_MODELVIEW8_ARB = constant.Constant( 'GL_MODELVIEW8_ARB', 0x8728 )
GL_MODELVIEW9_ARB = constant.Constant( 'GL_MODELVIEW9_ARB', 0x8729 )
GL_MODELVIEW10_ARB = constant.Constant( 'GL_MODELVIEW10_ARB', 0x872A )
GL_MODELVIEW11_ARB = constant.Constant( 'GL_MODELVIEW11_ARB', 0x872B )
GL_MODELVIEW12_ARB = constant.Constant( 'GL_MODELVIEW12_ARB', 0x872C )
GL_MODELVIEW13_ARB = constant.Constant( 'GL_MODELVIEW13_ARB', 0x872D )
GL_MODELVIEW14_ARB = constant.Constant( 'GL_MODELVIEW14_ARB', 0x872E )
GL_MODELVIEW15_ARB = constant.Constant( 'GL_MODELVIEW15_ARB', 0x872F )
GL_MODELVIEW16_ARB = constant.Constant( 'GL_MODELVIEW16_ARB', 0x8730 )
GL_MODELVIEW17_ARB = constant.Constant( 'GL_MODELVIEW17_ARB', 0x8731 )
GL_MODELVIEW18_ARB = constant.Constant( 'GL_MODELVIEW18_ARB', 0x8732 )
GL_MODELVIEW19_ARB = constant.Constant( 'GL_MODELVIEW19_ARB', 0x8733 )
GL_MODELVIEW20_ARB = constant.Constant( 'GL_MODELVIEW20_ARB', 0x8734 )
GL_MODELVIEW21_ARB = constant.Constant( 'GL_MODELVIEW21_ARB', 0x8735 )
GL_MODELVIEW22_ARB = constant.Constant( 'GL_MODELVIEW22_ARB', 0x8736 )
GL_MODELVIEW23_ARB = constant.Constant( 'GL_MODELVIEW23_ARB', 0x8737 )
GL_MODELVIEW24_ARB = constant.Constant( 'GL_MODELVIEW24_ARB', 0x8738 )
GL_MODELVIEW25_ARB = constant.Constant( 'GL_MODELVIEW25_ARB', 0x8739 )
GL_MODELVIEW26_ARB = constant.Constant( 'GL_MODELVIEW26_ARB', 0x873A )
GL_MODELVIEW27_ARB = constant.Constant( 'GL_MODELVIEW27_ARB', 0x873B )
GL_MODELVIEW28_ARB = constant.Constant( 'GL_MODELVIEW28_ARB', 0x873C )
GL_MODELVIEW29_ARB = constant.Constant( 'GL_MODELVIEW29_ARB', 0x873D )
GL_MODELVIEW30_ARB = constant.Constant( 'GL_MODELVIEW30_ARB', 0x873E )
GL_MODELVIEW31_ARB = constant.Constant( 'GL_MODELVIEW31_ARB', 0x873F )
glWeightbvARB = platform.createExtensionFunction( 
'glWeightbvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLbyteArray,),
doc='glWeightbvARB(GLint(size), GLbyteArray(weights)) -> None',
argNames=('size','weights',),
deprecated=_DEPRECATED,
)

glWeightsvARB = platform.createExtensionFunction( 
'glWeightsvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLshortArray,),
doc='glWeightsvARB(GLint(size), GLshortArray(weights)) -> None',
argNames=('size','weights',),
deprecated=_DEPRECATED,
)

glWeightivARB = platform.createExtensionFunction( 
'glWeightivARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLintArray,),
doc='glWeightivARB(GLint(size), GLintArray(weights)) -> None',
argNames=('size','weights',),
deprecated=_DEPRECATED,
)

glWeightfvARB = platform.createExtensionFunction( 
'glWeightfvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLfloatArray,),
doc='glWeightfvARB(GLint(size), GLfloatArray(weights)) -> None',
argNames=('size','weights',),
deprecated=_DEPRECATED,
)

glWeightdvARB = platform.createExtensionFunction( 
'glWeightdvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLdoubleArray,),
doc='glWeightdvARB(GLint(size), GLdoubleArray(weights)) -> None',
argNames=('size','weights',),
deprecated=_DEPRECATED,
)

glWeightubvARB = platform.createExtensionFunction( 
'glWeightubvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLubyteArray,),
doc='glWeightubvARB(GLint(size), GLubyteArray(weights)) -> None',
argNames=('size','weights',),
deprecated=_DEPRECATED,
)

glWeightusvARB = platform.createExtensionFunction( 
'glWeightusvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLushortArray,),
doc='glWeightusvARB(GLint(size), GLushortArray(weights)) -> None',
argNames=('size','weights',),
deprecated=_DEPRECATED,
)

glWeightuivARB = platform.createExtensionFunction( 
'glWeightuivARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLuintArray,),
doc='glWeightuivARB(GLint(size), GLuintArray(weights)) -> None',
argNames=('size','weights',),
deprecated=_DEPRECATED,
)

glWeightPointerARB = platform.createExtensionFunction( 
'glWeightPointerARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glWeightPointerARB(GLint(size), GLenum(type), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('size','type','stride','pointer',),
deprecated=_DEPRECATED,
)

glVertexBlendARB = platform.createExtensionFunction( 
'glVertexBlendARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,),
doc='glVertexBlendARB(GLint(count)) -> None',
argNames=('count',),
deprecated=_DEPRECATED,
)


def glInitVertexBlendARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.shader_buffer_load

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_shader_buffer_load'
_DEPRECATED = False
GL_BUFFER_GPU_ADDRESS_NV = constant.Constant( 'GL_BUFFER_GPU_ADDRESS_NV', 0x8F1D )
GL_GPU_ADDRESS_NV = constant.Constant( 'GL_GPU_ADDRESS_NV', 0x8F34 )
GL_MAX_SHADER_BUFFER_ADDRESS_NV = constant.Constant( 'GL_MAX_SHADER_BUFFER_ADDRESS_NV', 0x8F35 )
glMakeBufferResidentNV = platform.createExtensionFunction( 
'glMakeBufferResidentNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glMakeBufferResidentNV(GLenum(target), GLenum(access)) -> None',
argNames=('target','access',),
deprecated=_DEPRECATED,
)

glMakeBufferNonResidentNV = platform.createExtensionFunction( 
'glMakeBufferNonResidentNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glMakeBufferNonResidentNV(GLenum(target)) -> None',
argNames=('target',),
deprecated=_DEPRECATED,
)

glIsBufferResidentNV = platform.createExtensionFunction( 
'glIsBufferResidentNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLenum,),
doc='glIsBufferResidentNV(GLenum(target)) -> constants.GLboolean',
argNames=('target',),
deprecated=_DEPRECATED,
)

glNamedMakeBufferResidentNV = platform.createExtensionFunction( 
'glNamedMakeBufferResidentNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glNamedMakeBufferResidentNV(GLuint(buffer), GLenum(access)) -> None',
argNames=('buffer','access',),
deprecated=_DEPRECATED,
)

glNamedMakeBufferNonResidentNV = platform.createExtensionFunction( 
'glNamedMakeBufferNonResidentNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glNamedMakeBufferNonResidentNV(GLuint(buffer)) -> None',
argNames=('buffer',),
deprecated=_DEPRECATED,
)

glIsNamedBufferResidentNV = platform.createExtensionFunction( 
'glIsNamedBufferResidentNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsNamedBufferResidentNV(GLuint(buffer)) -> constants.GLboolean',
argNames=('buffer',),
deprecated=_DEPRECATED,
)

glGetBufferParameterui64vNV = platform.createExtensionFunction( 
'glGetBufferParameterui64vNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLuint64Array,),
doc='glGetBufferParameterui64vNV(GLenum(target), GLenum(pname), GLuint64Array(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetNamedBufferParameterui64vNV = platform.createExtensionFunction( 
'glGetNamedBufferParameterui64vNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLuint64Array,),
doc='glGetNamedBufferParameterui64vNV(GLuint(buffer), GLenum(pname), GLuint64Array(params)) -> None',
argNames=('buffer','pname','params',),
deprecated=_DEPRECATED,
)

glGetIntegerui64vNV = platform.createExtensionFunction( 
'glGetIntegerui64vNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLuint64Array,),
doc='glGetIntegerui64vNV(GLenum(value), GLuint64Array(result)) -> None',
argNames=('value','result',),
deprecated=_DEPRECATED,
)

glUniformui64NV = platform.createExtensionFunction( 
'glUniformui64NV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLuint64EXT,),
doc='glUniformui64NV(GLint(location), GLuint64EXT(value)) -> None',
argNames=('location','value',),
deprecated=_DEPRECATED,
)

glUniformui64vNV = platform.createExtensionFunction( 
'glUniformui64vNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLuint64Array,),
doc='glUniformui64vNV(GLint(location), GLsizei(count), GLuint64Array(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glGetUniformui64vNV = platform.createExtensionFunction( 
'glGetUniformui64vNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,arrays.GLuint64Array,),
doc='glGetUniformui64vNV(GLuint(program), GLint(location), GLuint64Array(params)) -> None',
argNames=('program','location','params',),
deprecated=_DEPRECATED,
)

glProgramUniformui64NV = platform.createExtensionFunction( 
'glProgramUniformui64NV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLuint64EXT,),
doc='glProgramUniformui64NV(GLuint(program), GLint(location), GLuint64EXT(value)) -> None',
argNames=('program','location','value',),
deprecated=_DEPRECATED,
)

glProgramUniformui64vNV = platform.createExtensionFunction( 
'glProgramUniformui64vNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLsizei,arrays.GLuint64Array,),
doc='glProgramUniformui64vNV(GLuint(program), GLint(location), GLsizei(count), GLuint64Array(value)) -> None',
argNames=('program','location','count','value',),
deprecated=_DEPRECATED,
)


def glInitShaderBufferLoadNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.convolution_accuracy

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_convolution_accuracy'
_DEPRECATED = False
GL_CONVOLUTION_HINT_SGIX = constant.Constant( 'GL_CONVOLUTION_HINT_SGIX', 0x8316 )


def glInitConvolutionAccuracySGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.present_video

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_present_video'
_DEPRECATED = False
GL_FRAME_NV = constant.Constant( 'GL_FRAME_NV', 0x8E26 )
GL_FIELDS_NV = constant.Constant( 'GL_FIELDS_NV', 0x8E27 )
GL_CURRENT_TIME_NV = constant.Constant( 'GL_CURRENT_TIME_NV', 0x8E28 )
GL_NUM_FILL_STREAMS_NV = constant.Constant( 'GL_NUM_FILL_STREAMS_NV', 0x8E29 )
GL_PRESENT_TIME_NV = constant.Constant( 'GL_PRESENT_TIME_NV', 0x8E2A )
GL_PRESENT_DURATION_NV = constant.Constant( 'GL_PRESENT_DURATION_NV', 0x8E2B )
glPresentFrameKeyedNV = platform.createExtensionFunction( 
'glPresentFrameKeyedNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint64EXT,constants.GLuint,constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLuint,constants.GLenum,constants.GLuint,constants.GLuint,),
doc='glPresentFrameKeyedNV(GLuint(video_slot), GLuint64EXT(minPresentTime), GLuint(beginPresentTimeId), GLuint(presentDurationId), GLenum(type), GLenum(target0), GLuint(fill0), GLuint(key0), GLenum(target1), GLuint(fill1), GLuint(key1)) -> None',
argNames=('video_slot','minPresentTime','beginPresentTimeId','presentDurationId','type','target0','fill0','key0','target1','fill1','key1',),
deprecated=_DEPRECATED,
)

glPresentFrameDualFillNV = platform.createExtensionFunction( 
'glPresentFrameDualFillNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint64EXT,constants.GLuint,constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLenum,constants.GLuint,constants.GLenum,constants.GLuint,constants.GLenum,constants.GLuint,),
doc='glPresentFrameDualFillNV(GLuint(video_slot), GLuint64EXT(minPresentTime), GLuint(beginPresentTimeId), GLuint(presentDurationId), GLenum(type), GLenum(target0), GLuint(fill0), GLenum(target1), GLuint(fill1), GLenum(target2), GLuint(fill2), GLenum(target3), GLuint(fill3)) -> None',
argNames=('video_slot','minPresentTime','beginPresentTimeId','presentDurationId','type','target0','fill0','target1','fill1','target2','fill2','target3','fill3',),
deprecated=_DEPRECATED,
)

glGetVideoivNV = platform.createExtensionFunction( 
'glGetVideoivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetVideoivNV(GLuint(video_slot), GLenum(pname), GLintArray(params)) -> None',
argNames=('video_slot','pname','params',),
deprecated=_DEPRECATED,
)

glGetVideouivNV = platform.createExtensionFunction( 
'glGetVideouivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLuintArray,),
doc='glGetVideouivNV(GLuint(video_slot), GLenum(pname), GLuintArray(params)) -> None',
argNames=('video_slot','pname','params',),
deprecated=_DEPRECATED,
)

glGetVideoi64vNV = platform.createExtensionFunction( 
'glGetVideoi64vNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLint64Array,),
doc='glGetVideoi64vNV(GLuint(video_slot), GLenum(pname), GLint64Array(params)) -> None',
argNames=('video_slot','pname','params',),
deprecated=_DEPRECATED,
)

glGetVideoui64vNV = platform.createExtensionFunction( 
'glGetVideoui64vNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLuint64Array,),
doc='glGetVideoui64vNV(GLuint(video_slot), GLenum(pname), GLuint64Array(params)) -> None',
argNames=('video_slot','pname','params',),
deprecated=_DEPRECATED,
)


def glInitPresentVideoNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.blend_alpha_minmax

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_blend_alpha_minmax'
_DEPRECATED = False
GL_ALPHA_MIN_SGIX = constant.Constant( 'GL_ALPHA_MIN_SGIX', 0x8320 )
GL_ALPHA_MAX_SGIX = constant.Constant( 'GL_ALPHA_MAX_SGIX', 0x8321 )


def glInitBlendAlphaMinmaxSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.seamless_cube_map

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_seamless_cube_map'
_DEPRECATED = False
GL_TEXTURE_CUBE_MAP_SEAMLESS = constant.Constant( 'GL_TEXTURE_CUBE_MAP_SEAMLESS', 0x884F )


def glInitSeamlessCubeMapARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.texture_rg

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_rg'
_DEPRECATED = False
GL_RG = constant.Constant( 'GL_RG', 0x8227 )
GL_RG_INTEGER = constant.Constant( 'GL_RG_INTEGER', 0x8228 )
GL_R8 = constant.Constant( 'GL_R8', 0x8229 )
GL_R16 = constant.Constant( 'GL_R16', 0x822A )
GL_RG8 = constant.Constant( 'GL_RG8', 0x822B )
GL_RG16 = constant.Constant( 'GL_RG16', 0x822C )
GL_R16F = constant.Constant( 'GL_R16F', 0x822D )
GL_R32F = constant.Constant( 'GL_R32F', 0x822E )
GL_RG16F = constant.Constant( 'GL_RG16F', 0x822F )
GL_RG32F = constant.Constant( 'GL_RG32F', 0x8230 )
GL_R8I = constant.Constant( 'GL_R8I', 0x8231 )
GL_R8UI = constant.Constant( 'GL_R8UI', 0x8232 )
GL_R16I = constant.Constant( 'GL_R16I', 0x8233 )
GL_R16UI = constant.Constant( 'GL_R16UI', 0x8234 )
GL_R32I = constant.Constant( 'GL_R32I', 0x8235 )
GL_R32UI = constant.Constant( 'GL_R32UI', 0x8236 )
GL_RG8I = constant.Constant( 'GL_RG8I', 0x8237 )
GL_RG8UI = constant.Constant( 'GL_RG8UI', 0x8238 )
GL_RG16I = constant.Constant( 'GL_RG16I', 0x8239 )
GL_RG16UI = constant.Constant( 'GL_RG16UI', 0x823A )
GL_RG32I = constant.Constant( 'GL_RG32I', 0x823B )
GL_RG32UI = constant.Constant( 'GL_RG32UI', 0x823C )


def glInitTextureRgARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.transform_feedback2

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_transform_feedback2'
_DEPRECATED = False
GL_TRANSFORM_FEEDBACK_NV = constant.Constant( 'GL_TRANSFORM_FEEDBACK_NV', 0x8E22 )
GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED_NV = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED_NV', 0x8E23 )
glget.addGLGetConstant( GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED_NV, (1,) )
GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE_NV = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE_NV', 0x8E24 )
glget.addGLGetConstant( GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE_NV, (1,) )
GL_TRANSFORM_FEEDBACK_BINDING_NV = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BINDING_NV', 0x8E25 )
glget.addGLGetConstant( GL_TRANSFORM_FEEDBACK_BINDING_NV, (1,) )
glBindTransformFeedbackNV = platform.createExtensionFunction( 
'glBindTransformFeedbackNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glBindTransformFeedbackNV(GLenum(target), GLuint(id)) -> None',
argNames=('target','id',),
deprecated=_DEPRECATED,
)

glDeleteTransformFeedbacksNV = platform.createExtensionFunction( 
'glDeleteTransformFeedbacksNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteTransformFeedbacksNV(GLsizei(n), GLuintArray(ids)) -> None',
argNames=('n','ids',),
deprecated=_DEPRECATED,
)

glGenTransformFeedbacksNV = platform.createExtensionFunction( 
'glGenTransformFeedbacksNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenTransformFeedbacksNV(GLsizei(n), GLuintArray(ids)) -> None',
argNames=('n','ids',),
deprecated=_DEPRECATED,
)

glIsTransformFeedbackNV = platform.createExtensionFunction( 
'glIsTransformFeedbackNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsTransformFeedbackNV(GLuint(id)) -> constants.GLboolean',
argNames=('id',),
deprecated=_DEPRECATED,
)

glPauseTransformFeedbackNV = platform.createExtensionFunction( 
'glPauseTransformFeedbackNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glPauseTransformFeedbackNV() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glResumeTransformFeedbackNV = platform.createExtensionFunction( 
'glResumeTransformFeedbackNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glResumeTransformFeedbackNV() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glDrawTransformFeedbackNV = platform.createExtensionFunction( 
'glDrawTransformFeedbackNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glDrawTransformFeedbackNV(GLenum(mode), GLuint(id)) -> None',
argNames=('mode','id',),
deprecated=_DEPRECATED,
)


def glInitTransformFeedback2NV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_1_2

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_1_2'
_DEPRECATED = False
GL_UNSIGNED_BYTE_3_3_2 = constant.Constant( 'GL_UNSIGNED_BYTE_3_3_2', 0x8032 )
GL_UNSIGNED_SHORT_4_4_4_4 = constant.Constant( 'GL_UNSIGNED_SHORT_4_4_4_4', 0x8033 )
GL_UNSIGNED_SHORT_5_5_5_1 = constant.Constant( 'GL_UNSIGNED_SHORT_5_5_5_1', 0x8034 )
GL_UNSIGNED_INT_8_8_8_8 = constant.Constant( 'GL_UNSIGNED_INT_8_8_8_8', 0x8035 )
GL_UNSIGNED_INT_10_10_10_2 = constant.Constant( 'GL_UNSIGNED_INT_10_10_10_2', 0x8036 )
GL_TEXTURE_BINDING_3D = constant.Constant( 'GL_TEXTURE_BINDING_3D', 0x806A )
GL_PACK_SKIP_IMAGES = constant.Constant( 'GL_PACK_SKIP_IMAGES', 0x806B )
GL_PACK_IMAGE_HEIGHT = constant.Constant( 'GL_PACK_IMAGE_HEIGHT', 0x806C )
GL_UNPACK_SKIP_IMAGES = constant.Constant( 'GL_UNPACK_SKIP_IMAGES', 0x806D )
GL_UNPACK_IMAGE_HEIGHT = constant.Constant( 'GL_UNPACK_IMAGE_HEIGHT', 0x806E )
GL_TEXTURE_3D = constant.Constant( 'GL_TEXTURE_3D', 0x806F )
GL_PROXY_TEXTURE_3D = constant.Constant( 'GL_PROXY_TEXTURE_3D', 0x8070 )
GL_TEXTURE_DEPTH = constant.Constant( 'GL_TEXTURE_DEPTH', 0x8071 )
GL_TEXTURE_WRAP_R = constant.Constant( 'GL_TEXTURE_WRAP_R', 0x8072 )
GL_MAX_3D_TEXTURE_SIZE = constant.Constant( 'GL_MAX_3D_TEXTURE_SIZE', 0x8073 )
GL_UNSIGNED_BYTE_2_3_3_REV = constant.Constant( 'GL_UNSIGNED_BYTE_2_3_3_REV', 0x8362 )
GL_UNSIGNED_SHORT_5_6_5 = constant.Constant( 'GL_UNSIGNED_SHORT_5_6_5', 0x8363 )
GL_UNSIGNED_SHORT_5_6_5_REV = constant.Constant( 'GL_UNSIGNED_SHORT_5_6_5_REV', 0x8364 )
GL_UNSIGNED_SHORT_4_4_4_4_REV = constant.Constant( 'GL_UNSIGNED_SHORT_4_4_4_4_REV', 0x8365 )
GL_UNSIGNED_SHORT_1_5_5_5_REV = constant.Constant( 'GL_UNSIGNED_SHORT_1_5_5_5_REV', 0x8366 )
GL_UNSIGNED_INT_8_8_8_8_REV = constant.Constant( 'GL_UNSIGNED_INT_8_8_8_8_REV', 0x8367 )
GL_UNSIGNED_INT_2_10_10_10_REV = constant.Constant( 'GL_UNSIGNED_INT_2_10_10_10_REV', 0x8368 )
GL_BGR = constant.Constant( 'GL_BGR', 0x80E0 )
GL_BGRA = constant.Constant( 'GL_BGRA', 0x80E1 )
GL_MAX_ELEMENTS_VERTICES = constant.Constant( 'GL_MAX_ELEMENTS_VERTICES', 0x80E8 )
GL_MAX_ELEMENTS_INDICES = constant.Constant( 'GL_MAX_ELEMENTS_INDICES', 0x80E9 )
GL_CLAMP_TO_EDGE = constant.Constant( 'GL_CLAMP_TO_EDGE', 0x812F )
GL_TEXTURE_MIN_LOD = constant.Constant( 'GL_TEXTURE_MIN_LOD', 0x813A )
GL_TEXTURE_MAX_LOD = constant.Constant( 'GL_TEXTURE_MAX_LOD', 0x813B )
GL_TEXTURE_BASE_LEVEL = constant.Constant( 'GL_TEXTURE_BASE_LEVEL', 0x813C )
GL_TEXTURE_MAX_LEVEL = constant.Constant( 'GL_TEXTURE_MAX_LEVEL', 0x813D )
GL_SMOOTH_POINT_SIZE_RANGE = constant.Constant( 'GL_SMOOTH_POINT_SIZE_RANGE', 0xB12 )
GL_SMOOTH_POINT_SIZE_GRANULARITY = constant.Constant( 'GL_SMOOTH_POINT_SIZE_GRANULARITY', 0xB13 )
GL_SMOOTH_LINE_WIDTH_RANGE = constant.Constant( 'GL_SMOOTH_LINE_WIDTH_RANGE', 0xB22 )
GL_SMOOTH_LINE_WIDTH_GRANULARITY = constant.Constant( 'GL_SMOOTH_LINE_WIDTH_GRANULARITY', 0xB23 )
GL_ALIASED_LINE_WIDTH_RANGE = constant.Constant( 'GL_ALIASED_LINE_WIDTH_RANGE', 0x846E )
glBlendColor = platform.createExtensionFunction( 
'glBlendColor',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLclampf,constants.GLclampf,constants.GLclampf,constants.GLclampf,),
doc='glBlendColor(GLclampf(red), GLclampf(green), GLclampf(blue), GLclampf(alpha)) -> None',
argNames=('red','green','blue','alpha',),
deprecated=_DEPRECATED,
)

glBlendEquation = platform.createExtensionFunction( 
'glBlendEquation',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glBlendEquation(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)

glDrawRangeElements = platform.createExtensionFunction( 
'glDrawRangeElements',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLsizei,constants.GLenum,ctypes.c_void_p,),
doc='glDrawRangeElements(GLenum(mode), GLuint(start), GLuint(end), GLsizei(count), GLenum(type), c_void_p(indices)) -> None',
argNames=('mode','start','end','count','type','indices',),
deprecated=_DEPRECATED,
)

glTexImage3D = platform.createExtensionFunction( 
'glTexImage3D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTexImage3D(GLenum(target), GLint(level), GLint(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('target','level','internalformat','width','height','depth','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTexSubImage3D = platform.createExtensionFunction( 
'glTexSubImage3D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTexSubImage3D(GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('target','level','xoffset','yoffset','zoffset','width','height','depth','format','type','pixels',),
deprecated=_DEPRECATED,
)

glCopyTexSubImage3D = platform.createExtensionFunction( 
'glCopyTexSubImage3D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,),
doc='glCopyTexSubImage3D(GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height)) -> None',
argNames=('target','level','xoffset','yoffset','zoffset','x','y','width','height',),
deprecated=_DEPRECATED,
)
# import legacy entry points to allow checking for bool(entryPoint)
from OpenGL.raw.GL.VERSION.GL_1_2_DEPRECATED import *



'''OpenGL extension EXT.stencil_clear_tag

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_stencil_clear_tag'
_DEPRECATED = False
GL_STENCIL_TAG_BITS_EXT = constant.Constant( 'GL_STENCIL_TAG_BITS_EXT', 0x88F2 )
GL_STENCIL_CLEAR_TAG_VALUE_EXT = constant.Constant( 'GL_STENCIL_CLEAR_TAG_VALUE_EXT', 0x88F3 )
glStencilClearTagEXT = platform.createExtensionFunction( 
'glStencilClearTagEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,constants.GLuint,),
doc='glStencilClearTagEXT(GLsizei(stencilTagBits), GLuint(stencilClearTag)) -> None',
argNames=('stencilTagBits','stencilClearTag',),
deprecated=_DEPRECATED,
)


def glInitStencilClearTagEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""ctypes-based OpenGL wrapper for Python

This is the PyOpenGL 3.x tree, it attempts to provide
a largely compatible API for code written with the 
PyOpenGL 2.x series using the ctypes foreign function 
interface system.

Configuration Variables:

There are a few configuration variables in this top-level
module.  Applications should be the only code that tweaks 
these variables, mid-level libraries should not take it 
upon themselves to disable/enable features at this level.
The implication there is that your library code should be 
able to work with any of the valid configurations available
with these sets of flags.

    ERROR_CHECKING -- if set to a False value before
        importing any OpenGL.* libraries will completely 
        disable error-checking.  This can dramatically
        improve performance, but makes debugging far 
        harder.
        
        This is intended to be turned off *only* in a 
        production environment where you *know* that 
        your code is entirely free of situations where you 
        use exception-handling to handle error conditions,
        i.e. where you are explicitly checking for errors 
        everywhere they can occur in your code.
        
        Default: True 

    ERROR_LOGGING -- If True, then wrap array-handler 
        functions with  error-logging operations so that all exceptions 
        will be reported to log objects in OpenGL.logs, note that 
        this means you will get lots of error logging whenever you 
        have code that tests by trying something and catching an 
        error, this is intended to be turned on only during 
        development so that you can see why something is failing.
        
        Errors are normally logged to the OpenGL.errors logger.
        
        Only triggers if ERROR_CHECKING is True
        
        Default: False
        
    ERROR_ON_COPY -- if set to a True value before 
        importing the numpy/lists support modules, will 
        cause array operations to raise 
        OpenGL.error.CopyError if the operation 
        would cause a data-copy in order to make the 
        passed data-type match the target data-type.
        
        This effectively disables all list/tuple array 
        support, as they are inherently copy-based.
        
        This feature allows for optimisation of your 
        application.  It should only be enabled during 
        testing stages to prevent raising errors on 
        recoverable conditions at run-time.  
        
        Note: this feature does not currently work with 
            numarray or Numeric arrays.
        
        Default: False
    
    CONTEXT_CHECKING -- if set to True, PyOpenGL will wrap 
        *every* GL and GLU call with a check to see if there 
        is a valid context.  If there is no valid context 
        then will throw OpenGL.errors.NoContext.  This is an 
        *extremely* slow check and is not enabled by default,
        intended to be enabled in order to track down (wrong)
        code that uses GL/GLU entry points before the context 
        has been initialized (something later Linux GLs are 
        very picky about).
        
        Default: False
    
    STORE_POINTERS -- if set to True, PyOpenGL array operations 
        will attempt to store references to pointers which are 
        being passed in order to prevent memory-access failures 
        if the pointed-to-object goes out of scope.  This 
        behaviour is primarily intended to allow temporary arrays 
        to be created without causing memory errors, thus it is 
        trading off performance for safety.
        
        To use this flag effectively, you will want to first set 
        ERROR_ON_COPY to True and eliminate all cases where you 
        are copying arrays.  Copied arrays *will* segfault your 
        application deep within the GL if you disable this feature!
        
        Once you have eliminated all copying of arrays in your 
        application, you will further need to be sure that all 
        arrays which are passed to the GL are stored for at least 
        the time period for which they are active in the GL.  That 
        is, you must be sure that your array objects live at least 
        until they are no longer bound in the GL.  This is something 
        you need to confirm by thinking about your application's 
        structure.
        
        When you are sure your arrays won't cause seg-faults, you 
        can set STORE_POINTERS=False in your application and enjoy 
        a (slight) speed up.
        
        Note: this flag is *only* observed when ERROR_ON_COPY == True,
            as a safety measure to prevent pointless segfaults
        
        Default: True
    
    WARN_ON_FORMAT_UNAVAILABLE -- If True, generates
        logging-module warn-level events when a FormatHandler
        plugin is not loadable (with traceback).
    
        Default: False
    
    FULL_LOGGING -- If True, then wrap functions with 
        logging operations which reports each call along with its 
        arguments to  the OpenGL.calltrace logger at the INFO 
        level.  This is *extremely* slow.  You should *not* enable 
        this in production code! 
        
        You will need to have a  logging configuration (e.g. 
            logging.basicConfig() 
        ) call  in your top-level script to see the results of the 
        logging.
        
        Default: False
    
    ALLOW_NUMPY_SCALARS -- if True, we will wrap 
        all GLint/GLfloat calls conversions with wrappers 
        that allow for passing numpy scalar values.
        
        Note that this is experimental, *not* reliable,
        and very slow!
        
        Note that byte/char types are not wrapped.
        
        Default: False
    
    UNSIGNED_BYTE_IMAGES_AS_STRING -- if True, we will return
        GL_UNSIGNED_BYTE image-data as strings, istead of arrays
        for glReadPixels and glGetTexImage

        Default: True
    
    FORWARD_COMPATIBLE_ONLY -- only include OpenGL 3.1 compatible 
        entry points.  Note that this will generally break most 
        PyOpenGL code that hasn't been explicitly made "legacy free"
        via a significant rewrite.
    
        Default: False
        
    SIZE_1_ARRAY_UNPACK -- if True, unpack size-1 arrays to be 
        scalar values, as done in PyOpenGL 1.5 -> 3.0.0, that is,
        if a glGenList( 1 ) is done, return a uint rather than 
        an array of uints.

        Default: True
    
    USE_ACCELERATE -- if True, attempt to use the OpenGL_accelerate
        package to provide Cython-coded accelerators for core wrapping
        operations.
        
        Default: True
"""
from OpenGL.version import __version__

ERROR_CHECKING = True
ERROR_LOGGING = False
ERROR_ON_COPY = False
ARRAY_SIZE_CHECKING = True
STORE_POINTERS = True
WARN_ON_FORMAT_UNAVAILABLE = False
FORWARD_COMPATIBLE_ONLY = False
SIZE_1_ARRAY_UNPACK = True
USE_ACCELERATE = True
CONTEXT_CHECKING = False

FULL_LOGGING = False 
ALLOW_NUMPY_SCALARS = False
UNSIGNED_BYTE_IMAGES_AS_STRING = True

# Declarations of plugins provided by PyOpenGL itself
from OpenGL.plugins import PlatformPlugin, FormatHandler
PlatformPlugin( 'nt', 'OpenGL.platform.win32.Win32Platform' )
PlatformPlugin( 'linux2', 'OpenGL.platform.glx.GLXPlatform' )
PlatformPlugin( 'darwin', 'OpenGL.platform.darwin.DarwinPlatform' )
PlatformPlugin( 'posix', 'OpenGL.platform.glx.GLXPlatform' )

FormatHandler( 'none', 'OpenGL.arrays.nones.NoneHandler' )
FormatHandler( 'str', 'OpenGL.arrays.strings.StringHandler' )
FormatHandler( 'list', 'OpenGL.arrays.lists.ListHandler', ['__builtin__.list','__builtin__.tuple'] )
FormatHandler( 'numbers', 'OpenGL.arrays.numbers.NumberHandler' )
FormatHandler( 
    'ctypesarray', 'OpenGL.arrays.ctypesarrays.CtypesArrayHandler',
    [
        '_ctypes.ArrayType',
    ],
)
FormatHandler( 
    'ctypesparameter',
    'OpenGL.arrays.ctypesparameters.CtypesParameterHandler',
)
FormatHandler( 'ctypespointer', 'OpenGL.arrays.ctypespointers.CtypesPointerHandler' )
FormatHandler( 'numpy', 'OpenGL.arrays.numpymodule.NumpyHandler', ['numpy.ndarray'] )
FormatHandler( 'numeric', 'OpenGL.arrays.numeric.NumericHandler', )



'''OpenGL extension IBM.rasterpos_clip

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_IBM_rasterpos_clip'
_DEPRECATED = False
GL_RASTER_POSITION_UNCLIPPED_IBM = constant.Constant( 'GL_RASTER_POSITION_UNCLIPPED_IBM', 0x19262 )
glget.addGLGetConstant( GL_RASTER_POSITION_UNCLIPPED_IBM, (1,) )


def glInitRasterposClipIBM():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
